Debian Administration - Debian Administration Resources
Description: Tips for a Debian GNU/Linux System Administrator.
Keywords: Debian System Administration News, Debian Sysadmin, Linux Administration, Linux Sysadmin, Sysadmin

# Debian Administration

- About
- Archive
- Contribute
- FAQ
- Search
- Tags

## Setting up your own graphical git-server with gitbucket

Posted by Steve on Tue 14 Oct 2014 at 09:18
Tags: git, nginx

This article documents the process of configuring a git host, using gitbucket, which will give you a graphical interface to a collection of git repositories, accessible via any browser, along with support for groups, issues, and forks.

( Read 664 more words ~ 9 comments posted )

## Using the haproxy load-balancer for increased availability

Posted by Steve on Wed 27 Aug 2014 at 14:12
Tags: haproxy, load balancing, reverse proxy

`HAProxy` is a TCP/HTTP load-balancer, allowing you to route incoming traffic destined for one address to a number of different back-ends. The routing is very flexible and it can be a useful component of a high-availability setup.

( Read 1774 more words ~ 4 comments posted )

## Automating the Debian installer with PXE and preseeding

Posted by Steve on Sat 23 Aug 2014 at 12:34
Tags: amd64, dnsmasq, kvm, preseeding, pxe, wheezy

This article is designed to introduce the process of PXE-booting a host directly into the Debian installer, and then automating the installation via the Debian PreSeed configuration. Both of these topics have been covered in the past, but not together - and we'll also include notes on testing this setup with KVM.

( Read 1230 more words ~ 5 comments posted )

## Disabling Apache logging of particular requests

Posted by Steve on Thu 7 Aug 2014 at 10:26
Tags: apache2, cronolog, logging, nginx

I've got a webserver which runs a particular service, and that service is sufficiently interesting and important that I run monitoring probes against it every 30 seconds. Those particular requests clutter my logs, and here is a brief note on how to avoid that clutter.

( Read 292 more words ~ 5 comments posted )

## GNU Make 4.0 released, including support for plugins

Posted by Steve on Sun 11 May 2014 at 11:31
Tags: make

The new upload of GNU Make 4.0 recently reached Debian's unstable distribution, and has also migrated to the testing distribution, currently codenamed "jessie". GNU Make 4.0 brings in several new features, perhaps the most interesting of which is support for the use of plugins.

( Read 530 more words ~ 3 comments posted )

## Debian 7: 7.5 released

Posted by ajt on Sat 26 Apr 2014 at 18:27
Tags: debian releases

The Debian project is pleased to announce the fifth update of its stable distribution Debian 7 (codename "wheezy"). This update mainly adds corrections for security problems to the stable release, along with a few adjustments for serious problems. Security advisories were already published separately and are referenced where available.

( Read 189 more words ~ 0 comments posted )

## OpenSSL Heartbeat, a.k.a. Heartbleed Bug

Posted by ajt on Tue 8 Apr 2014 at 22:24
Tags: bug, openssl, security, ssl, tls

A serious security flaw has come to light in the OpenSSL package used in many Linux distributions including Debian. It is considered very serious and all administrators should patch their systems at once and restart any services that rely on OpenSSL.

( Read 88 more words ~ 5 comments posted )

## A brief introduction to server-testing with serverspec

Posted by Steve on Thu 13 Mar 2014 at 10:16
Tags: cfengine, ruby, serverspec, slaughter

Serverspec is the name of a Ruby tool which allows you to write simple tests, to validate that a server is correctly configured. Here we'll walk through the installation of the tool, and show how it can be used to test a server setup.

( Read 1183 more words ~ 0 comments posted )

## Hiding processes from other users

Posted by Steve on Thu 13 Mar 2014 at 08:58
Tags: proc, security

If you run a multi-user system it can increase security if you hide the display of running processes, and their arguments, which belong to other users. This helps avoid problems if users enter passwords on the command-line, and similar.

( Read 293 more words ~ 5 comments posted )

## Debian 6.0: 6.0.9 released

Posted by ajt on Mon 17 Feb 2014 at 22:23
Tags: debian releases

The Debian project is pleased to announce the ninth update of its oldstable distribution Debian 6.0 (codename "squeeze"). This update mainly adds corrections for security problems to the oldstable release, along with a few adjustments for serious problems. Security advisories were already published separately and are referenced where available.

( Read 181 more words ~ 0 comments posted )

#### Sign In

Username:

Password:

[Register|Advanced]

### Flattr

### Current Poll

What do you use for configuration management?

Chef
Puppet
SaltStack
CFEngine
Other tool
Nothing
( 754 votes ~ 10 comments )

### Recent Weblogs

It's been 7 Years
by rkreider
GnuPG 2.1.0 in debian experimental
by dkg
8 comments
Site code is public once again.
by Steve
1 comment
Using Amazon SES with Exim (Submission)
by lee
Web Application Vulnerability scanners
by simonw
Strange Dovecot behaviour solved
by ajt
1 comment
Problem with Bonding and Vlan on Wheezy
by fugit
1 comment
I have a Debian server again
by blackm
Hello World!
by cisco
Planning for Disk Encryption
by tong

Archived weblogs

### Recent Tips

Site code is public once again.
by Steve
1 comment
You should be using ssh-agent
by dkg
16 comments
Finding packages not directly depended upon
by fsateler
1 comment
Blocking mail in exim4 based on the sender NS
by lee
1 comment
resetting passphrases for mapped LUKS volumes
by dkg
8 comments
forwarding unix domain sockets with ssh and socat
by dkg
6 comments
Avoiding erroneous OpenPGP certifications
by dkg
3 comments
use logger(1) to reduce sysadmin mail
by rossen
IPv6 address updated
by Steve
4 comments
New SSL certificate
by Steve
15 comments